@@ -2,13 +2,15 @@
     %prog [options] files
 """
 import sys
+import os
+import os.path as op
+from itertools import izip
+import urllib
+
 import gzip
 import bz2
-from itertools import izip
 from subprocess import Popen, PIPE
-import urllib
 import csv
-import os.path as op
 
 dialect = csv.excel
 
@@ -55,6 +57,7 @@ def tokens(line, sep="\t"):
     """
     return line.rstrip("\r\n").split(sep)
 
+
 def header(fname, sep="\t"):
     """
     just grab the header from a given file
@@ -98,8 +101,26 @@ def reader(fname, header=True, sep="\t"):
         for toks in line_gen:
             yield toks
 
+def is_newer_b(a, bfiles):
+    """
+    check that all b files have been modified more recently than a
+    """
+    if isinstance(bfiles, basestring):
+        bfiles = [bfiles]
+
+    if not op.exists(a): return False
+    if not all(op.exists(b) for b in bfiles): return False
+
+    atime = os.stat(a).st_mtime # modification time
+    for b in bfiles:
+        # a has been modified since
+        if atime > os.stat(b).st_mtime: 
+            return False
+    return True
+
+
+
 if __name__ == "__main__":
     import doctest
-    if doctest.testmod(optionflags=doctest.ELLIPSIS |\
-                                   doctest.NORMALIZE_WHITESPACE).failed == 0:
-        pass
+    doctest.testmod(optionflags=doctest.ELLIPSIS |\
+                                   doctest.NORMALIZE_WHITESPACE)
